# Changelog

## 0.4.2 (2026-01-13)

Full Changelog: [v0.4.1...v0.4.2](https://github.com/ArkHQ-io/ark-python/compare/v0.4.1...v0.4.2)

### Chores

* configure new SDK language ([5fb3ec6](https://github.com/ArkHQ-io/ark-python/commit/5fb3ec6ce80d2486e39a89e84b4a16ac486746b7))

## 0.4.1 (2026-01-13)

Full Changelog: [v0.4.0...v0.4.1](https://github.com/ArkHQ-io/ark-python/compare/v0.4.0...v0.4.1)

### Chores

* update SDK settings ([e071de7](https://github.com/ArkHQ-io/ark-python/commit/e071de7d5303bce685aaee2839f7e9b56c84395c))

## 0.4.0 (2026-01-13)

Full Changelog: [v0.3.0...v0.4.0](https://github.com/ArkHQ-io/ark-python/compare/v0.3.0...v0.4.0)

### Features

* **api:** api update ([6c4cc66](https://github.com/ArkHQ-io/ark-python/commit/6c4cc666424e3c1a1aac56ec4536cf4ed3537ace))
* **api:** manual updates ([776e67f](https://github.com/ArkHQ-io/ark-python/commit/776e67f921ea69fb2b7dc33322ebef1a1e05b84d))

## 0.3.0 (2026-01-13)

Full Changelog: [v0.2.0...v0.3.0](https://github.com/ArkHQ-io/ark-python/compare/v0.2.0...v0.3.0)

### Features

* **api:** api update ([ac4c3d7](https://github.com/ArkHQ-io/ark-python/commit/ac4c3d7059fab55e8da4a9f93ffb3413515129fe))
* **api:** manual updates ([17331e6](https://github.com/ArkHQ-io/ark-python/commit/17331e6d8533aef33fb6984754d8ddbca3aaa994))
* **api:** manual updates ([05fbd0c](https://github.com/ArkHQ-io/ark-python/commit/05fbd0c0683d6b40cf3a9b4d07ee21602a938f4d))
* **api:** manual updates ([5d6498c](https://github.com/ArkHQ-io/ark-python/commit/5d6498c0923a34baa3b8cdc6bd70b92eb122c559))
* **api:** manual updates ([07e7603](https://github.com/ArkHQ-io/ark-python/commit/07e76030e28a03aa1c94cd94fc920e47ccabb13b))
* **api:** manual updates ([d03ff5d](https://github.com/ArkHQ-io/ark-python/commit/d03ff5db9843f7561b8825f4070a3d36da434e61))
* **api:** manual updates ([adc040d](https://github.com/ArkHQ-io/ark-python/commit/adc040df33836303bfeb2e1a255cb8ec6bdaea02))
* **api:** manual updates ([600c059](https://github.com/ArkHQ-io/ark-python/commit/600c05906b89ab47a43f8032dd08ad687dc68473))
* **api:** manual updates ([e41f3fc](https://github.com/ArkHQ-io/ark-python/commit/e41f3fc1143d2125115f063c58e8ea75b60e3479))
* **api:** manual updates ([f54f602](https://github.com/ArkHQ-io/ark-python/commit/f54f60266db5c4fd5b5d6cbb076d5ccc43d30ff1))

## 0.2.0 (2026-01-12)

Full Changelog: [v0.1.0...v0.2.0](https://github.com/ArkHQ-io/ark-python/compare/v0.1.0...v0.2.0)

### Features

* **api:** api update ([7690a6d](https://github.com/ArkHQ-io/ark-python/commit/7690a6d828f6adaa02b245f6c88e61aa7846200c))

## 0.1.0 (2026-01-12)

Full Changelog: [v0.0.2...v0.1.0](https://github.com/ArkHQ-io/ark-python/compare/v0.0.2...v0.1.0)

### Features

* **api:** api update ([e46f650](https://github.com/ArkHQ-io/ark-python/commit/e46f650c617e11e1173068ebbb36ac607612e40d))
* **api:** api update ([be470af](https://github.com/ArkHQ-io/ark-python/commit/be470affdcf987f8c0b90aabddee8301593ed41c))

## 0.0.2 (2026-01-12)

Full Changelog: [v0.0.1...v0.0.2](https://github.com/ArkHQ-io/ark-python/compare/v0.0.1...v0.0.2)

### Chores

* configure new SDK language ([c32b083](https://github.com/ArkHQ-io/ark-python/commit/c32b08338547890f0b366a0b6b8f38e4c5289b86))
* update SDK settings ([1fc666c](https://github.com/ArkHQ-io/ark-python/commit/1fc666c5a3d8e8f23ca6f3b9824bf9c2ccc0e4a0))
* update SDK settings ([ddfd3fe](https://github.com/ArkHQ-io/ark-python/commit/ddfd3fec94f3badd64b949699772a74790799951))
